package com.ruoyi.abuwx.controller;

import com.ruoyi.abuwx.domain.WbMaintenanceInformation;
import com.ruoyi.abuwx.service.IWbMaintenanceInformationService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 维保记录Controller
 *
 * @author ruoyi
 * @date 2024-04-09
 */
@RestController
@RequestMapping("/abuwx/information")
public class WbMaintenanceInformationController extends BaseController
{
    @Autowired
    private IWbMaintenanceInformationService wbMaintenanceInformationService;

    /**
     * 查询维保记录列表
     */
    @GetMapping("/list")
    public TableDataInfo list(WbMaintenanceInformation wbMaintenanceInformation)
    {
        startPage();
        List<WbMaintenanceInformation> list = wbMaintenanceInformationService.selectWbMaintenanceInformationList(wbMaintenanceInformation);
        return getDataTable(list);
    }

    /**
     * 导出维保记录列表
     */
    @Log(title = "维保记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WbMaintenanceInformation wbMaintenanceInformation)
    {
        List<WbMaintenanceInformation> list = wbMaintenanceInformationService.selectWbMaintenanceInformationList(wbMaintenanceInformation);
        ExcelUtil<WbMaintenanceInformation> util = new ExcelUtil<WbMaintenanceInformation>(WbMaintenanceInformation.class);
        util.exportExcel(response, list, "维保记录数据");
    }

    /**
     * 获取维保记录详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wbMaintenanceInformationService.selectWbMaintenanceInformationById(id));
    }

    /**
     * 新增维保记录
     */
    @Log(title = "维保记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WbMaintenanceInformation wbMaintenanceInformation)
    {
        return toAjax(wbMaintenanceInformationService.insertWbMaintenanceInformation(wbMaintenanceInformation));
    }

    /**
     * 修改维保记录
     */
    @Log(title = "维保记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WbMaintenanceInformation wbMaintenanceInformation)
    {
        return toAjax(wbMaintenanceInformationService.updateWbMaintenanceInformation(wbMaintenanceInformation));
    }

    /**
     * 删除维保记录
     */
    @Log(title = "维保记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wbMaintenanceInformationService.deleteWbMaintenanceInformationByIds(ids));
    }
}
