package com.ruoyi.abuwx.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.abuwx.domain.WbMaintenanceInformation;
import com.ruoyi.abuwx.mapper.WbMaintenanceInformationMapper;
import com.ruoyi.abuwx.service.IWbMaintenanceInformationService;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

/**
 * 维保记录Service业务层处理
 *
 * @author ruoyi
 * @date 2024-04-09
 */
@Service
public class WbMaintenanceInformationServiceImpl extends ServiceImpl<WbMaintenanceInformationMapper, WbMaintenanceInformation>
        implements IWbMaintenanceInformationService
{
    @Autowired
    private WbMaintenanceInformationMapper wbMaintenanceInformationMapper;

    @Autowired
    private IWbMaintenanceInformationService iWbMaintenanceInformationService;

    /**
     * 查询维保记录
     *
     * @param id 维保记录主键
     * @return 维保记录
     */
    @Override
    public WbMaintenanceInformation selectWbMaintenanceInformationById(Long id)
    {
        return wbMaintenanceInformationMapper.selectWbMaintenanceInformationById(id);
    }

    /**
     * 查询维保记录列表
     *
     * @param wbMaintenanceInformation 维保记录
     * @return 维保记录
     */
    @Override
    public List<WbMaintenanceInformation> selectWbMaintenanceInformationList(WbMaintenanceInformation wbMaintenanceInformation)
    {
        return wbMaintenanceInformationMapper.selectWbMaintenanceInformationList(wbMaintenanceInformation);
    }

    /**
     * 新增维保记录
     *
     * @param wbMaintenanceInformation 维保记录
     * @return 结果
     */
    @Override
    public int insertWbMaintenanceInformation(WbMaintenanceInformation wbMaintenanceInformation)
    {
        wbMaintenanceInformation.setCreateTime(DateUtils.getNowDate());
        return wbMaintenanceInformationMapper.insertWbMaintenanceInformation(wbMaintenanceInformation);
    }

    /**
     * 修改维保记录
     *
     * @param wbMaintenanceInformation 维保记录
     * @return 结果
     */
    @Override
    public int updateWbMaintenanceInformation(WbMaintenanceInformation wbMaintenanceInformation)
    {
        wbMaintenanceInformation.setUpdateTime(DateUtils.getNowDate());
        return wbMaintenanceInformationMapper.updateWbMaintenanceInformation(wbMaintenanceInformation);
    }

    /**
     * 批量删除维保记录
     *
     * @param ids 需要删除的维保记录主键
     * @return 结果
     */
    @Override
    public int deleteWbMaintenanceInformationByIds(Long[] ids)
    {
        return wbMaintenanceInformationMapper.deleteWbMaintenanceInformationByIds(ids);
    }

    /**
     * 删除维保记录信息
     *
     * @param id 维保记录主键
     * @return 结果
     */
    @Override
    public int deleteWbMaintenanceInformationById(Long id)
    {
        return wbMaintenanceInformationMapper.deleteWbMaintenanceInformationById(id);
    }

    /**
     * 根据项目id查询维保记录列表
     *
     * @param projectId 项目id
     * @return 结果
     */
    @Override
    public List<WbMaintenanceInformation> selectWbMaintenanceInformationListByProjectId(Long projectId) {
        List<WbMaintenanceInformation> list = iWbMaintenanceInformationService.list();
        List<WbMaintenanceInformation> collect = list.stream().filter(data -> data.getProjectId() != null
                && data.getProjectId().equals(projectId)).collect(Collectors.toList());
        return collect;
    }
}
